package com.lining.code.spark.product.model;

import com.lining.code.constant.ESIndexConstant;
import com.lining.code.constant.SQLConstant;
import com.lining.code.enums.DataTypeEnum;
import com.lining.code.enums.DayEnum;
import com.lining.code.util.DateUtil;
import com.lining.code.util.SparkSessionUtil;
import org.apache.spark.sql.Dataset;
import org.apache.spark.sql.Row;
import org.apache.spark.sql.SaveMode;
import org.apache.spark.sql.SparkSession;

import java.text.MessageFormat;

/**
 * @ Author ：lining.
 * @ Date ：Created in 22:30 2022/5/9
 * @ Description：产品列表数据同步
 */
public class ProductListModel03Action {

    public static void main(String[] args) {
        SparkSession spark = SparkSessionUtil.getSparkSession("ProductListModel03Action");
        String date = DateUtil.getCurrentDate();
//        spark.udf().register("DateFormatUdf", new MyUdf(), DataTypes.StringType);
        if(args != null && args.length > 0){
            date = args[0];
            syncDataByDate(spark, date);
        }else{
            syncData(spark);
        }

        spark.stop();

    }


    public static void syncData(SparkSession spark){
        String gameSQL = MessageFormat.format(SQLConstant.PRODUCT_LIST_MODEL_SQL,
                DayEnum.DAY_03.getName(), DataTypeEnum.GAME.getType());

        String gameIndex = MessageFormat.format(ESIndexConstant.PRODUCT_LIST_INDEX,
                DataTypeEnum.GAME.getName(), DayEnum.DAY_03.getName());

        Dataset<Row> gameSet = spark.sql(gameSQL);


        gameSet.write()
                .format("org.elasticsearch.spark.sql")
                .mode(SaveMode.Overwrite)
                .option("es.mapping.id", "id")
                .save(gameIndex);

        String appSQL = MessageFormat.format(SQLConstant.PRODUCT_LIST_MODEL_SQL,
                DayEnum.DAY_03.getName(), DataTypeEnum.APP.getType());

        String appIndex = MessageFormat.format(ESIndexConstant.PRODUCT_LIST_INDEX,
                DataTypeEnum.APP.getName(), DayEnum.DAY_03.getName());

        Dataset<Row> appSet = spark.sql(appSQL);

        appSet.write()
                .format("org.elasticsearch.spark.sql")
                .mode(SaveMode.Overwrite)
                .option("es.mapping.id", "id")
                .save(appIndex);

    }

    public static void syncDataByDate(SparkSession spark, String date){
        String gameSQL = MessageFormat.format(SQLConstant.PRODUCT_LIST_MODEL_SQL,
                DayEnum.DAY_03.getName(), DataTypeEnum.GAME.getType());

        String gameIndex = MessageFormat.format(ESIndexConstant.PRODUCT_LIST_DATE_INDEX,
                DataTypeEnum.GAME.getName(), DayEnum.DAY_03.getName(), date);

        Dataset<Row> gameSet = spark.sql(gameSQL);

        gameSet.write()
                .format("org.elasticsearch.spark.sql")
                .mode(SaveMode.Overwrite)
                .option("es.mapping.id", "id")
                .save(gameIndex);

        String appSQL = MessageFormat.format(SQLConstant.PRODUCT_LIST_MODEL_SQL,
                DayEnum.DAY_03.getName(), DataTypeEnum.APP.getType());

        String appIndex = MessageFormat.format(ESIndexConstant.PRODUCT_LIST_DATE_INDEX,
                DataTypeEnum.APP.getName(), DayEnum.DAY_03.getName(), date);

        Dataset<Row> appSet = spark.sql(appSQL);

        appSet.write()
                .format("org.elasticsearch.spark.sql")
                .mode(SaveMode.Overwrite)
                .option("es.mapping.id", "id")
                .save(appIndex);

    }
}
